@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2019 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2023 by the Free Software Foundation, Inc.
 #
 # This file is part of Django-Mailman.
 #
@@ -19,13 +19,21 @@
 #
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
+import logging
 
 from django.apps import AppConfig
 
 
+# For a library, adding a NullHandler is a good idea. If the Django project
+# wants, they can configure the handler in LOGGING config for `django_mailman3`
+# logger.
+log = logging.getLogger(__name__)
+log.addHandler(logging.NullHandler())
+
+
 class DjangoMailman3Config(AppConfig):
     name = 'django_mailman3'
     verbose_name = "Django Mailman 3"
 
     def ready(self):
-        import django_mailman3.signals    # noqa: F401
+        import django_mailman3.signals  # noqa: F401
